==> qtcreator_4.14.1.orig.tar.xz: qt-creator-opensource-src-4.14.1/src/plugins/compilationdatabaseprojectmanager/compilationdatabasetests.h <==
/****************************************************************************
**
** Copyright (C) 2018 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <QObject>
#include <memory>

namespace CppTools { namespace Tests { class TemporaryCopiedDir; } }

namespace CompilationDatabaseProjectManager {

class CompilationDatabaseTests : public QObject
{
    Q_OBJECT
public:
    explicit CompilationDatabaseTests(QObject *parent = nullptr);
    ~CompilationDatabaseTests();

private slots:
    void initTestCase();
    void cleanupTestCase();
    void testProject();
    void testProject_data();

private:
    void addTestRow(const QByteArray &relativeFilePath);

    std::unique_ptr<CppTools::Tests::TemporaryCopiedDir> m_tmpDir;
};

} // namespace CompilationDatabaseProjectManager

==> qtcreator_6.0.2.orig.tar.xz: qt-creator-opensource-src-6.0.2/src/plugins/compilationdatabaseprojectmanager/compilationdatabasetests.h <==
/****************************************************************************
**
** Copyright (C) 2018 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <QObject>
#include <memory>

namespace CppEditor { namespace Tests { class TemporaryCopiedDir; } }

namespace CompilationDatabaseProjectManager {
namespace Internal {

class CompilationDatabaseTests : public QObject
{
    Q_OBJECT
public:
    explicit CompilationDatabaseTests(QObject *parent = nullptr);
    ~CompilationDatabaseTests();

private slots:
    void initTestCase();
    void cleanupTestCase();
    void testProject();
    void testProject_data();
    void testFilterEmptyFlags();
    void testFilterFromFilename();
    void testFilterArguments();
    void testSplitFlags();
    void testSplitFlagsWithEscapedQuotes();
    void testFilterCommand();
    void testFileKindDifferentFromExtension();
    void testFileKindDifferentFromExtension2();
    void testSkipOutputFiles();

private:
    void addTestRow(const QByteArray &relativeFilePath);

    std::unique_ptr<CppEditor::Tests::TemporaryCopiedDir> m_tmpDir;
};

} // namespace Internal
} // namespace CompilationDatabaseProjectManager
